@@ -386,30 +386,23 @@ test_that("Relative survival", {
     bc$bh <- rep(0.01, nrow(bc))
 
     ## Compare with stata stgenreg, using Weibull PH model
-
-    hweibullPH <- function(x, shape, scale = 1, log=FALSE){
-        hweibull(x, shape=shape, scale=scale^{-1/shape}, log=log)
-    }
-    HweibullPH <- function(x, shape, scale=1, log=FALSE){
-        Hweibull(x, shape=shape, scale=scale^{-1/shape}, log=log)
-    }
-    custom.weibullPH <- list(name="weibullPH", 
-                             pars=c("shape","scale"), location="scale",
-                             transforms=c(log, log), inv.transforms=c(exp, exp),
-                             inits = function(t){
-                                 c(1, median(t[t>0]) / log(2))
-                             })
-
-    suppressWarnings({  # warnings from temporary overflow during optimisation 
-      fs6b <- flexsurvreg(Surv(recyrs, censrec) ~ group, data=bc, dist=custom.weibullPH, bhazard=bh, dfns=list(h=hweibullPH, H=HweibullPH))
-      fs6bd <- flexsurvreg(Surv(recyrs, censrec) ~ group, data=bc, dist="weibullPH", bhazard=bh)
-    })
+    fs6b <- flexsurvreg(Surv(recyrs, censrec) ~ group, data=bc, dist="weibullPH", bhazard=bh)
     
     expect_equal(log(fs6b$res[1,"est"]), 0.3268327417773233, tol=1e-05)
     expect_equal(log(fs6b$res[2,"est"]), -3.5308925743338038, tol=1e-05)
-    expect_equal(fs6b$res["groupMedium","est"], 0.9343799681269026, tol=1e-05)
-    expect_equal(fs6b$res["groupPoor","est"], 1.799204192587765, tol=1e-05)
+    expect_equal(fs6b$res["groupMedium","est"], 0.9343799681269026, tol=1e-04)
+    expect_equal(fs6b$res["groupPoor","est"], 1.799204192587765, tol=1e-04)
 
+    ## Check fit from 3 par model reduces to 1 par 
+    ## Deriv calculation bug causing false convergence fixed in 2.1
+    fshgg <- flexsurvreg(Surv(recyrs, censrec) ~ group, data=bc, dist="gengamma", 
+                         inits=c(1,1,1), fixedpars=2:3, bhazard=bh)
+    fshe <-  flexsurvreg(Surv(recyrs, censrec) ~ group, data=bc, dist="exponential", bhazard=bh)
+    fshw <-  flexsurvreg(Surv(recyrs, censrec) ~ group, data=bc, dist="weibull", 
+                         inits = c(1,10), fixedpars=1, bhazard=bh)
+    expect_equal(fshgg$loglik, fshe$loglik, tol=1e-06)
+    expect_equal(fshgg$loglik, fshw$loglik, tol=1e-06)
+    
     ## same results as 
     ## cd /home/chris/flexsurv/stata
     ## use stpm/bc
@@ -418,8 +411,16 @@ test_that("Relative survival", {
     ## gen bh = 0.01
     ## stset recyrs, failure(censrec)
     ## stgenreg, loghazard([ln_lambda] :+ [ln_gamma] :+ (exp([ln_gamma]) :- 1) :* log(#t)) nodes(100) ln_lambda(group2 group3) bhazard(bh)
-### don't know what scale Stata returns the loglik on
 
+    ## Check we can convert from partial to full likelihood by adding the
+    ## sum of the cumulative hazards 
+    mdl_0 <- flexsurvreg(Surv(time/365, status == 2) ~ 1, data = lung, dist = "exp")
+    bhaz <- 0.1
+    mdl_1 <- flexsurvreg(Surv(time/365, status == 2) ~ 1, dist = "exp", data = lung, 
+                         inits = mdl_0$res[, "est"] - bhaz, 
+                         fixedpars = TRUE, bhazard = rep(bhaz, nrow(lung)))
+  
+    expect_equal(mdl_0$loglik, mdl_1$loglik - sum(bhaz * lung$time/365))
 })
 
 test_that("warning with strata", { 
