@@ -10,7 +10,7 @@ bln.markov <- flexsurvreg(Surv(Tstart, Tstop, status) ~ trans, data=bosms3, dist
 
 test_that("msfit.flexsurvreg",{
     mexp <- msfit.flexsurvreg(bexp, t=0.01, trans=tmat, tvar="trans")
-    summ <- summary.flexsurvreg(bexp, t=0.01, type="cumhaz", ci=FALSE, newdata=list(trans=factor(1:3, levels=1:3)))
+    summ <- summary(bexp, t=0.01, type="cumhaz", ci=FALSE, newdata=list(trans=factor(1:3, levels=1:3)))
     summ <- as.numeric(unlist(lapply(summ, function(x)x$est[x$time==0.01])))   
     expect_equal(mexp$Haz$Haz[mexp$Haz$time==0.01], summ)
     mwei <- msfit.flexsurvreg(bwei, t=c(0.01, 0.02), trans=tmat, tvar="trans", B=10)
@@ -25,9 +25,11 @@ bexp.cov <- flexsurvreg(Surv(years, status) ~ trans + x, data=bosms3, dist="exp"
 bexp.markov.cov <- flexsurvreg(Surv(Tstart, Tstop, status) ~ trans + x, data=bosms3, dist="exp")
 
 test_that("newdata in msfit.flexsurvreg",{
-    msfit.flexsurvreg(bexp.cov, newdata=list(x=1), t=c(0,5,10), trans=tmat, variance=FALSE)
-    msfit.flexsurvreg(bexp.cov, newdata=list(x=2), t=c(0,5,10), trans=tmat, variance=FALSE)
-    msfit.flexsurvreg(bexp.cov, newdata=list(x=c(1,2,3)), t=c(0,5,10), trans=tmat, variance=FALSE)
+    expect_error({
+        msfit.flexsurvreg(bexp.cov, newdata=list(x=1), t=c(0,5,10), trans=tmat, variance=FALSE)
+        msfit.flexsurvreg(bexp.cov, newdata=list(x=2), t=c(0,5,10), trans=tmat, variance=FALSE)
+        msfit.flexsurvreg(bexp.cov, newdata=list(x=c(1,2,3)), t=c(0,5,10), trans=tmat, variance=FALSE)
+    }, NA)
 })
 
 test_that("Errors in msfit.flexsurvreg",{
@@ -56,18 +58,22 @@ test_that("totlos.fs",{
 })
 
 test_that("pmatrix.simfs",{
-    pmatrix.simfs(bexp, t=5, trans=tmat, M=100)
-    pmatrix.simfs(bwei, t=5, trans=tmat, M=100)
-    pmatrix.simfs(bexp.cov, t=5, trans=tmat, newdata=list(x=1), M=100)
+    expect_error({
+        pmatrix.simfs(bexp, t=5, trans=tmat, M=100)
+        pmatrix.simfs(bwei, t=5, trans=tmat, M=100)
+        pmatrix.simfs(bexp.cov, t=5, trans=tmat, newdata=list(x=1), M=100)
+    }, NA)
 })
 
 test_that("totlos.simfs",{
-    totlos.simfs(bexp, t=5, trans=tmat, M=100)
-    totlos.simfs(bwei, t=5, trans=tmat, M=100)
-    totlos.simfs(bexp.cov, t=5, trans=tmat, newdata=list(x=1), M=100)
-    totlos.simfs(bexp, t=5, trans=tmat, M=100)
-    totlos.simfs(bwei, t=5, trans=tmat, M=100)
-    totlos.simfs(bexp.cov, t=5, trans=tmat, newdata=list(x=1), M=100)
+    expect_error({
+        totlos.simfs(bexp, t=5, trans=tmat, M=100)
+        totlos.simfs(bwei, t=5, trans=tmat, M=100)
+        totlos.simfs(bexp.cov, t=5, trans=tmat, newdata=list(x=1), M=100)
+        totlos.simfs(bexp, t=5, trans=tmat, M=100)
+        totlos.simfs(bwei, t=5, trans=tmat, M=100)
+        totlos.simfs(bexp.cov, t=5, trans=tmat, newdata=list(x=1), M=100)
+    }, NA)
 })
 
 ### List format for independent transition-specific models
@@ -109,9 +115,13 @@ test_that("list format in output functions", {
 })
 
 test_that("list and non-list format give same estimates", { 
-    expect_equal(pars.fmsm(bwei, trans=tmat), pars.fmsm(bwei.list, trans=tmat), tol=1e-04)
+    expect_equal(
+        as.numeric(pars.fmsm(bwei, trans=tmat)[[1]]),
+        as.numeric(pars.fmsm(bwei.list, trans=tmat)[[1]]), tol=1e-04)
     bexpci <- flexsurvreg(Surv(years, status) ~ trans*x, data=bosms3, dist="exp")
-    expect_equal(pars.fmsm(bexpci, newdata=list(x=1), trans=tmat), pars.fmsm(bexpc.list, newdata=list(x=1), trans=tmat), tol=1e-05)
+    expect_equal(
+        as.numeric(pars.fmsm(bexpci, newdata=list(x=1), trans=tmat)[[2]]),
+        as.numeric(pars.fmsm(bexpc.list, newdata=list(x=1), trans=tmat)[[2]]), tol=1e-05)
 
     expect_equal(pmatrix.fs(bwei, trans=tmat), pmatrix.fs(bwei.list, trans=tmat), tol=1e-04)
     expect_equal(totlos.fs(bwei, trans=tmat), totlos.fs(bwei.list, trans=tmat), tol=1e-04)
@@ -123,3 +133,22 @@ test_that("list and non-list format give same estimates", {
 })
 
 
+
+test_that("different model families for different transitions", { 
+
+blist <- vector(3, mode="list")
+blist[[1]] <- flexsurvreg(Surv(years, status) ~ 1, subset=(trans==1), data=bosms3, dist="exp")
+blist[[2]] <- flexsurvreg(Surv(years, status) ~ 1, subset=(trans==2), data=bosms3, dist="gamma")
+blist[[3]] <- flexsurvreg(Surv(years, status) ~ 1, subset=(trans==3), data=bosms3, dist="weibull")
+expect_equal(pmatrix.fs(blist, t=c(5,10), trans=tmat)$`5`[1,2], 0.2423839, tol=1e-04)
+expect_equal(totlos.fs(blist, trans=tmat)[1,2], 0.08277735, tol=1e-04)
+
+blistx <- vector(3, mode="list")
+blistx[[1]] <- flexsurvreg(Surv(years, status) ~ x, subset=(trans==1), data=bosms3, dist="exp")
+blistx[[2]] <- flexsurvreg(Surv(years, status) ~ x, subset=(trans==2), data=bosms3, dist="gamma")
+blistx[[3]] <- flexsurvreg(Surv(years, status) ~ x, subset=(trans==3), data=bosms3, dist="weibull")
+expect_equal(pmatrix.fs(blistx, t=c(5,10), trans=tmat, newdata=list(x=1))$`5`[1,2], 0.2291726, tol=1e-04)
+expect_equal(totlos.fs(blistx, trans=tmat, newdata=list(x=1))[1,2],0.08698692 , tol=1e-04)
+
+    
+})
